@@ -210,8 +210,8 @@ gst_rtsp_session_media_matches (GstRTSPSessionMedia * media,
  *
  * Get the #GstRTSPMedia that was used when constructing @media
  *
- * Returns: (transfer none): the #GstRTSPMedia of @media. Remains valid as long
- * as @media is valid.
+ * Returns: (transfer none) (nullable): the #GstRTSPMedia of @media.
+ * Remains valid as long as @media is valid.
  */
 GstRTSPMedia *
 gst_rtsp_session_media_get_media (GstRTSPSessionMedia * media)
@@ -387,8 +387,8 @@ gst_rtsp_session_media_set_transport (GstRTSPSessionMedia * media,
  *
  * Get a previously created #GstRTSPStreamTransport for the stream at @idx.
  *
- * Returns: (transfer none): a #GstRTSPStreamTransport that is valid until the
- * session of @media is unreffed.
+ * Returns: (transfer none) (nullable): a #GstRTSPStreamTransport that is
+ * valid until the session of @media is unreffed.
  */
 GstRTSPStreamTransport *
 gst_rtsp_session_media_get_transport (GstRTSPSessionMedia * media, guint idx)
@@ -407,6 +407,31 @@ gst_rtsp_session_media_get_transport (GstRTSPSessionMedia * media, guint idx)
   return result;
 }
 
+/**
+ * gst_rtsp_session_media_get_transports:
+ * @media: a #GstRTSPSessionMedia
+ *
+ * Get a list of all available #GstRTSPStreamTransport in this session.
+ *
+ * Returns: (transfer full) (element-type GstRTSPStreamTransport): a
+ * list of #GstRTSPStreamTransport, g_ptr_array_unref () after usage.
+ */
+GPtrArray *
+gst_rtsp_session_media_get_transports (GstRTSPSessionMedia * media)
+{
+  GstRTSPSessionMediaPrivate *priv;
+  GPtrArray *result;
+
+  g_return_val_if_fail (GST_IS_RTSP_SESSION_MEDIA (media), NULL);
+  priv = media->priv;
+
+  g_mutex_lock (&priv->lock);
+  result = g_ptr_array_ref (priv->transports);
+  g_mutex_unlock (&priv->lock);
+
+  return result;
+}
+
 /**
  * gst_rtsp_session_media_alloc_channels:
  * @media: a #GstRTSPSessionMedia
