@@ -67,7 +67,7 @@ static const gchar session_id_charset[] =
   'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z', 'A', 'B', 'C', 'D',
   'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S',
   'T', 'U', 'V', 'W', 'X', 'Y', 'Z', '0', '1', '2', '3', '4', '5', '6', '7',
-  '8', '9', '$', '-', '_', '.', '+'
+  '8', '9', '-', '_', '.', '+'  /* '$' Live555 in VLC strips off $ chars */
 };
 
 enum
@@ -341,7 +341,7 @@ create_session (GstRTSPSessionPool * pool, const gchar * id)
  *
  * Create a new #GstRTSPSession object in @pool.
  *
- * Returns: (transfer full): a new #GstRTSPSession.
+ * Returns: (transfer full) (nullable): a new #GstRTSPSession.
  */
 GstRTSPSession *
 gst_rtsp_session_pool_create (GstRTSPSessionPool * pool)
